# {py:mod}`ngff_zarr.methods`

```{py:module} ngff_zarr.methods
```

```{autodoc2-docstring} ngff_zarr.methods
:allowtitles:
```

## Submodules

```{toctree}
:titlesonly:
:maxdepth: 1

ngff_zarr.methods._itkwasm
ngff_zarr.methods._dask_image
ngff_zarr.methods._itk
ngff_zarr.methods._support
```

## Package Contents

### Data

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`methods <ngff_zarr.methods.methods>`
  - ```{autodoc2-docstring} ngff_zarr.methods.methods
    :summary:
    ```
* - {py:obj}`methods_values <ngff_zarr.methods.methods_values>`
  - ```{autodoc2-docstring} ngff_zarr.methods.methods_values
    :summary:
    ```
* - {py:obj}`Methods <ngff_zarr.methods.Methods>`
  - ```{autodoc2-docstring} ngff_zarr.methods.Methods
    :summary:
    ```
````

### API

````{py:data} methods
:canonical: ngff_zarr.methods.methods
:value: >
   [('ITKWASM_GAUSSIAN', 'itkwasm_gaussian'), ('ITKWASM_BIN_SHRINK', 'itkwasm_bin_shrink'), ('ITKWASM_L...

```{autodoc2-docstring} ngff_zarr.methods.methods
```

````

````{py:data} methods_values
:canonical: ngff_zarr.methods.methods_values
:value: >
   None

```{autodoc2-docstring} ngff_zarr.methods.methods_values
```

````

````{py:data} Methods
:canonical: ngff_zarr.methods.Methods
:value: >
   'Enum(...)'

```{autodoc2-docstring} ngff_zarr.methods.Methods
```

````
